pub struct CursorMutModel<Key, Value> {
pub keys: Seq<Key>,
pub position: int,
pub map: Map<Key, Value>,
}Expand description
The abstract state of a mutable B-tree cursor.
A cursor points at the gap immediately before keys[position]. Therefore, peek_next
accesses keys[position], while peek_prev accesses keys[position - 1].
Fields
keys: Seq<Key>All keys in the underlying map, in strictly increasing order.
position: intThe index of the element immediately after the cursor.
map: Map<Key, Value>The current contents of the complete map borrowed by the cursor.
Implementations
Sourceimpl<Key, Value> CursorMutModel<Key, Value>
impl<Key, Value> CursorMutModel<Key, Value>